@@ -1,5 +1,5 @@
 package App::gimpgitbuild::Command::build;
-$App::gimpgitbuild::Command::build::VERSION = '0.24.0';
+$App::gimpgitbuild::Command::build::VERSION = '0.26.0';
 use strict;
 use warnings;
 use autodie;
@@ -13,18 +13,6 @@ use App::gimpgitbuild::API::GitBuild ();
 use App::gimpgitbuild::API::Worker   ();
 use Git::Sync::App                   ();
 
-sub _process_executor
-{
-    my $self = shift;
-
-    if (@_)
-    {
-        $self->{_process_executor} = shift;
-    }
-
-    return $self->{_process_executor};
-}
-
 sub description
 {
     return "build gimp from git";
@@ -88,15 +76,10 @@ sub execute
         die "Unsupported process-exe '$_process_executor'!";
     }
 
-    my $fh     = \*STDIN;
-    my $obj    = App::gimpgitbuild::API::GitBuild->new;
-    my $worker = App::gimpgitbuild::API::Worker->new;
-    $worker->_api_obj($obj);
-    $worker->_mode($mode);
-    $worker->_process_executor($_process_executor);
+    my $worker = App::gimpgitbuild::API::Worker->new(
+        { _mode => $mode, _process_executor => $_process_executor, } );
 
-    my $HOME = $obj->home_dir;
-    my $env  = $obj->new_env;
+    my $env = App::gimpgitbuild::API::GitBuild->new()->new_env();
     $ENV{PATH}            = $env->{PATH};
     $ENV{PKG_CONFIG_PATH} = $env->{PKG_CONFIG_PATH};
     $ENV{XDG_DATA_DIRS}   = $env->{XDG_DATA_DIRS};
@@ -121,7 +104,7 @@ __END__
 
 =head1 VERSION
 
-version 0.24.0
+version 0.26.0
 
 =begin foo return (
         [ "output|o=s", "Output path" ],
