@@ -1,5 +1,5 @@
 package App::gimpgitbuild::Command::cleanbuild;
-$App::gimpgitbuild::Command::cleanbuild::VERSION = '0.24.0';
+$App::gimpgitbuild::Command::cleanbuild::VERSION = '0.26.0';
 use strict;
 use warnings;
 use autodie;
@@ -9,8 +9,7 @@ use App::gimpgitbuild -command;
 
 use File::Which qw/ which /;
 
-use App::gimpgitbuild::API::GitBuild ();
-use App::gimpgitbuild::API::Worker   ();
+use App::gimpgitbuild::API::Worker ();
 
 sub description
 {
@@ -33,14 +32,8 @@ sub execute
 {
     my ( $self, $opt, $args ) = @_;
 
-    my $mode              = 'clean';
-    my $_process_executor = 'perl';
-
-    my $obj    = App::gimpgitbuild::API::GitBuild->new;
-    my $worker = App::gimpgitbuild::API::Worker->new;
-    $worker->_api_obj($obj);
-    $worker->_mode($mode);
-    $worker->_process_executor($_process_executor);
+    my $worker = App::gimpgitbuild::API::Worker->new(
+        { _mode => 'clean', _process_executor => 'perl', } );
 
     $worker->_run_the_mode_on_all_repositories();
 
@@ -60,7 +53,7 @@ __END__
 
 =head1 VERSION
 
-version 0.24.0
+version 0.26.0
 
 =begin foo return (
         [ "output|o=s", "Output path" ],
